@@ -34,7 +34,7 @@ lambdaTree <- function(phy, lambda)
 ## checked 11 dec 07; works fine
 ## Modified Jan 2. 08 by Steve Kembel to work when trees have internal branch labels
 
-deltaTree <- function (phy, delta, rescale = F) 
+deltaTree <- function (phy, delta, rescale = T) 
 {
     tmp <- as.numeric(phy$edge)
     times <- branching.times(phy)
